{
           "10GBIC-empty.gif"    => {
                                      flood => { color => 'grey20' },
                                      h     => 18,
                                      w     => 42
                                    },
           "10GBIC-Green.gif"    => {
                                      flood => { color => 'green2' },
                                      h     => 18,
                                      w     => 42
                                    },
           "7606_front.gif"      => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 560,
                                      w      => 728
                                    },
           "c356024_2p.gif"      => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 80,
                                      w      => 660
                                    },
           "c356024g_4p.gif"     => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 80,
                                      w      => 660
                                    },
           "c3560_8_1.gif"       => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 80,
                                      w      => 490
                                    },
           "c3580_24_PoE.gif"    => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 80,
                                      w      => 660
                                    },
           "c375024_2.gif"       => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 80,
                                      w      => 660
                                    },
           "c375048_4p.gif"      => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 80,
                                      w      => 660
                                    },
           "c3750g24_4p.gif"     => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 80,
                                      w      => 660
                                    },
           "c3750g_12s.gif"      => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 80,
                                      w      => 660
                                    },
           "e100BaseF-green.gif" => {
                                      flood => { color => 'green2' },
                                      h     => 19,
                                      w     => 20
                                    },
           "e100BaseF-white.gif" => {
                                      flood => { color => 'snow1' },
                                      h     => 19,
                                      w     => 20
                                    },
           "GBIC-empty.gif"      => {
                                      flood => { color => 'grey20' },
                                      h     => 22,
                                      w     => 44
                                    },
           "GBIC-green.gif"      => {
                                      flood => { color => 'green2' },
                                      h     => 22,
                                      w     => 44
                                    },
           "gray.gif"            => {
                                      flood => { color => 'plum' },
                                      h     => 15,
                                      w     => 19
                                    },
           "green.gif"           => {
                                      flood => { color => 'green2' },
                                      h     => 15,
                                      w     => 19
                                    },
           "POSGBIC-empty.gif"   => {
                                      flood => { color => 'grey20' },
                                      h     => 22,
                                      w     => 44
                                    },
           "sfp_empty_gray.gif"  => {
                                      flood => { color => 'grey20' },
                                      h     => 16,
                                      w     => 21
                                    },
           "sfp_gray.gif"        => {
                                      flood => { color => 'plum' },
                                      h     => 16,
                                      w     => 21
                                    },
           "sfp_green.gif"       => {
                                      flood => { color => 'green2' },
                                      h     => 16,
                                      w     => 21
                                    },
           "sfp_tx_gray.gif"     => {
                                      flood => { color => 'plum' },
                                      h     => 16,
                                      w     => 21
                                    },
           "sfp_tx_green.gif"    => {
                                      flood => { color => 'green2' },
                                      h     => 16,
                                      w     => 21
                                    },
           "WS-SUP7203BXL.gif"   => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'bisque1',
                                                  fg    => 'LightYellow',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 81,
                                      w      => 667
                                    },
           "wssvcfwm1.gif"       => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'bisque1',
                                                  fg    => 'LightYellow',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 81,
                                      w      => 667
                                    },
           "wsx6408agbic.gif"    => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'bisque1',
                                                  fg    => 'LightYellow',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 81,
                                      w      => 667
                                    },
           "wsx6524mm.gif"       => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'bisque1',
                                                  fg    => 'LightYellow',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 81,
                                      w      => 667
                                    },
           "wsx670410ge.gif"     => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'bisque1',
                                                  fg    => 'LightYellow',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 81,
                                      w      => 667
                                    },
           "wsx6724sfp.gif"      => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'bisque1',
                                                  fg    => 'LightYellow',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 81,
                                      w      => 667
                                    },
           "ws-x6x06-rear.gif"   => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 712,
                                      w      => 728
                                    },
           "ws-x6x09-rear.gif"   => {
                                      border => 'SteelBlue4',
                                      flood  => { fill => {
                                                  bg    => 'wheat',
                                                  fg    => 'beige',
                                                  hatch => 'check4x4'
                                                } },
                                      h      => 955,
                                      w      => 728
                                    }
}
